@@ -1,6 +1,6 @@
 from sqlalchemy import create_engine
 from sqlalchemy import ForeignKey
-from sqlalchemy import func
+from sqlalchemy import func, distinct
 from sqlalchemy import over
 from sqlalchemy import inspect
 
@@ -20,7 +20,10 @@ import datetime
 Init db engine
 """
 #engine = create_engine('sqlite:///:memory:', echo=False)
-engine = create_engine('sqlite:///test.db''check_same_thread=true&timeout=10&mode=ro&nolock=1&uri=true', echo=False)
+engine = create_engine('sqlite:///test.sqlite?''uri=true&check_same_thread=False&timeout=10', echo=False)
+
+
+
 
 Base = declarative_base()
 
@@ -113,6 +116,19 @@ def search(params, order_by = None, order_direction = None, limit = None, offset
     return _to_dict(query)
 
 
+def search_summary(params, order_by = None, order_direction = None, limit = None, offset = None):
+    """Search and return summaries
+    """
+
+    query = _search(params, order_by, order_direction, limit, offset)
+
+    query = _get_summaries(query)
+
+    return _to_dict(query)
+
+
+
+
 def search_first(params, order_by = None, order_direction = None, limit = None, skip = None):
 
     query = _search(params, order_by, order_direction, 1, 0)
@@ -148,9 +164,6 @@ def commit():
 
     return
 
-
-
-
 """
 Methods
 """
@@ -158,7 +171,7 @@ Methods
 def list_record_types():
     """Return list of dict with record_types and number for each
     """
-    query = session.query(func.count(Observation.record_type), Observation.record_type).group_by(Observation.record_type).all()
+    query = session.query(func.count(distinct(Observation.record_id)), Observation.record_type).group_by(Observation.record_type).all()
 
     records = []
     for n, t in query:
@@ -220,17 +233,6 @@ def _get_summaries(query):
 
     subquery1 = query
 
-    if 1 == 0:
-        # Get max cred for each key
-        obs1 = aliased(Observation)
-        subquery1 = session.query(obs1)
-
-        # Filter 
-        if record_type:
-            subquery1 = subquery1.filter(obs1.record_type == record_type)
-        
-        if record_id:
-            subquery1 = subquery1.filter(obs1.record_id == record_id)
     subquery1 = subquery1.subquery()
 
     # Filter for top credibility
@@ -399,7 +401,7 @@ def _search(params, order_by = None, order_direction = None, limit = None, offse
 
     # apply order_by
     if order_by:
-        query = query.order_by("record_type")
+        query = query.order_by(order_by)
 
 
     # apply limit and offset
@@ -413,6 +415,15 @@ def _search(params, order_by = None, order_direction = None, limit = None, offse
     return query
 
 
+
+
+
+
+"""
+Methods: transformation
+"""
+
+
 def _to_dict_single(record):
 
 
